@@ -5,6 +5,7 @@ from . import play
 from . import points
 
 def file():
+	global temp
 	temp=loc()
 	play.save_opened(temp)
 	play.wavefile.close()
@@ -14,6 +15,9 @@ def loc():
 	return points.fpath(play.entry.get_text(),"temp")
 
 def close():
-	temp=loc()
-	if os.path.exists(temp):
-		os.remove(temp)
+	#temp=loc()
+	try:  #can change the entry and temp need to be the last one, but then can be nothing, then use try
+		if os.path.exists(temp):
+			os.remove(temp)
+	except:
+		pass
